@@ -1,10 +1,29 @@
 /*
  * Miscellaneous routines for Mathomatic.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
+#if	UNIX || CYGWIN
+#include <sys/ioctl.h>
+#include <termios.h>
+#endif
 
 /*
  * Standard function to report an error to the user.
@@ -94,10 +113,34 @@ check_err()
 	}
 }
 
+#if	UNIX || CYGWIN
+/*
+ * Get the screen (window) width and height from the operating system.
+ *
+ * Sets the global integers screen_columns and screen_rows.
+ */
+void
+get_screen_size()
+{
+	struct winsize	ws;
+
+	ws.ws_col = 0;
+	ws.ws_row = 0;
+	if (ioctl(1, TIOCGWINSZ, &ws) >= 0) {
+		if (ws.ws_col > 0) {
+			screen_columns = ws.ws_col;
+		}
+		if (ws.ws_row > 0) {
+			screen_rows = ws.ws_row;
+		}
+	}
+}
+#endif
+
 /*
  * Allocate the needed global expression storage arrays.
- * Each has "n_tokens" elements.
- * "n_tokens" must not change until Mathomatic terminates.
+ * Each is static and can hold n_tokens elements.
+ * n_tokens must not change until Mathomatic terminates.
  *
  * init_mem() is only called once upon Mathomatic startup
  * before using the symbolic math engine,
@@ -170,6 +213,7 @@ init_gvars()
 	symb_flag = false;
 	sign_cmp_flag = false;
 	approximate_roots = false;
+	repeat_flag = false;
 
 	/* initialize the universal and often used constant "0" expression */
 	zero_token.level = 1;
@@ -191,11 +235,12 @@ clean_up()
 	int	i;
 
 	init_gvars();		/* reset the global variables to the default */
-	if (gfp != stdout) {	/* reset the output file to standard output */
+	if (gfp != default_out) {	/* reset the output file to default */
 #if	!SECURE
-		fclose(gfp);
+		if (gfp != stdout && gfp != stderr)
+			fclose(gfp);
 #endif
-		gfp = stdout;
+		gfp = default_out;
 	}
 	for (i = 0; i < n_equations; i++) {
 		if (n_lhs[i] <= 0) {
@@ -257,7 +302,7 @@ long	*vp;
 }
 
 /*
- * Erase all equation spaces.
+ * Erase all equation spaces and initialize the global variables.
  * Similar to a restart.
  */
 void
@@ -677,7 +722,7 @@ int	n;		/* maximum size of "string" in bytes */
 	if (i >= 0 && string[i] == '\n') {
 		string[i] = '\0';
 	}
-	if (gfp != stdout || echo_input) {
+	if ((gfp != stdout && gfp != stderr) || echo_input) {
 		/* Input that is prompted for is now included in the redirected output
 		   of a command to a file, making redirection like logging. */
 		fprintf(gfp, "%s%s\n", prompt_str, string);
@@ -728,13 +773,13 @@ int	en;	/* equation space number the result is in */
 		return false;
 	}
 #if	LIBRARY
+	make_fractions_and_group(en);
+	if (factor_int_flag) {
+		factor_int_sub(en);
+	}
+	free_result_str();
+	result_str = list_equation(en, false);
 	if (gfp == stdout) {
-		make_fractions_and_group(en);
-		if (factor_int_flag) {
-			factor_int_sub(en);
-		}
-		free_result_str();
-		result_str = list_equation(en, false);
 		return(result_str != NULL);
 	}
 #endif
