@@ -1,7 +1,22 @@
 /*
  * Main include file for Mathomatic.  Can be edited.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #ifndef	max
@@ -135,6 +150,14 @@ typedef struct {		/* qsort(3) data structure for sorting Mathomatic variables */
 	int	count;		/* number of times the variable occurs */
 } sort_type;
 
+/* A list of supported output languages as described */
+enum language_list {
+  C = 1,      /* or C++ */
+  JAVA = 2,
+  PYTHON = 3
+};
+
+
 /* Debugging macros: */
 #if	SILENT
 #define	list_tdebug(level)
