@@ -1,7 +1,22 @@
 /*
  * Mathomatic commands that don't belong anywhere else.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -54,10 +69,10 @@ char	*cp;	/* the command line argument */
 	}
 	if (strchr(cp, 'y')) {
 		printf(_("Performing 3D surface plot...\n"));
-		snprintf(cl, sizeof(cl), "echo 'splot %s'|gnuplot -persist", cp);
+		snprintf(cl, sizeof(cl), "echo 'set grid; splot %s'|gnuplot -persist", cp);
 	} else {
 		printf(_("Performing 2D plot...\n"));
-		snprintf(cl, sizeof(cl), "echo 'plot %s'|gnuplot -persist", cp);
+		snprintf(cl, sizeof(cl), "echo 'set grid; plot %s'|gnuplot -persist", cp);
 	}
 	if (free_cp)
 		free(cp);
@@ -793,11 +808,6 @@ FILE	*ofp;	/* output file pointer */
 	}
 	fprintf(ofp, "display2d\n");
 
-	if (quiet_mode) {
-		fprintf(ofp, "no ");
-	}
-	fprintf(ofp, "prompt\n");
-
 	if (!preserve_surds) {
 		fprintf(ofp, "no ");
 	}
@@ -1011,6 +1021,10 @@ try_next_param:
 		quiet_mode = negate;
 		goto try_next_param;
 	}
+	if (strncasecmp(option_string, "html", 4) == 0) {
+		html_flag = !negate;
+		goto try_next_param;
+	}
 	if (strncasecmp(option_string, "preserve", 8) == 0) {
 		preserve_surds = !negate;
 		goto try_next_param;
@@ -1406,7 +1420,7 @@ char	*cp;
 	int		n;
 	int		diff_sign;
 	char		buf[MAX_CMD_LEN];
-	int		factor_flag = false, repeat_flag = false, value_entered;
+	int		factor_flag = false, value_entered;
 
 	if (current_not_defined()) {
 		return false;
@@ -1744,7 +1758,7 @@ char	*cp;
 			fprintf(gfp, _("Expressions differ.\n"));
 			return false;
 		}
-		error(_("Cannot compare an expression with an equation."));
+		error(_("Cannot compare an equation with a non-equation."));
 		return false;
 	}
 	if (compare_es(i, j)) {
@@ -1828,6 +1842,29 @@ times_neg1:
 		return 2;	/* equations identical, but LHS variable name differs */
 }
 
+/*
+ * Display the specified floating point value.
+ * If it is equal to a simple fraction, display that too.
+ *
+ * Return true if a fraction was displayed.
+ */
+int
+display_fraction(value)
+double	value;
+{
+	double	d4, d5;
+	int	rv = false;
+
+	f_to_fraction(value, &d4, &d5);
+	fprintf(gfp, "%.*g", precision, value);
+	if (d5 != 1.0) {
+		fprintf(gfp, " = %.*g/%.*g", precision, d4, precision, d5);
+		rv = true;
+	}
+	fprintf(gfp, "\n");
+	return rv;
+}
+
 /*
  * The divide command.
  */
@@ -1851,14 +1888,15 @@ char	*cp;
 			return false;
 	}
 	i = next_espace();
+do_repeat:
 /* prompt for the two operands */
 	my_strlcpy(prompt_str, _("Enter dividend: "), sizeof(prompt_str));
 	if (!get_expr(rhs[i], &nright)) {
-		return false;
+		return repeat_flag;
 	}
 	my_strlcpy(prompt_str, _("Enter divisor: "), sizeof(prompt_str));
 	if (!get_expr(lhs[i], &nleft)) {
-		return false;
+		return repeat_flag;
 	}
 	fprintf(gfp, "\n");
 /* simplify the operand expressions */
@@ -1881,6 +1919,8 @@ char	*cp;
 		d2 = fabs(d2);
 		if (d3 == 0.0) {
 			fprintf(gfp, _("No GCD found.\n"));
+			if (repeat_flag)
+				goto do_repeat;
 			return true;
 		}
 		fprintf(gfp, "GCD = ");
@@ -1896,6 +1936,8 @@ char	*cp;
 		} else {
 			display_fraction(lcm);
 		}
+		if (repeat_flag)
+			goto do_repeat;
 		return true;
 	}
 /* else do complex number division if 2 complex numbers were entered */
@@ -1903,6 +1945,8 @@ char	*cp;
 		c3 = complex_div(c1, c2);
 		fprintf(gfp, _("Result of complex number division:\n"));
 		fprintf(gfp, "%.*g %+.*g*i\n\n", precision, c3.re, precision, c3.im);
+		if (repeat_flag)
+			goto do_repeat;
 		return true;
 	}
 /* else do polynomial division and univariate GCD display */
@@ -1913,10 +1957,10 @@ char	*cp;
 		list_var(v_tmp, 0);
 		fprintf(gfp, _("Polynomial division successful using base variable (%s).\n"), var_str);
 		fprintf(gfp, _("The quotient is:\n"));
-		display_fractions_and_group(tlhs, &n_tlhs);
+		fractions_and_group(tlhs, &n_tlhs);
 		list_factor(tlhs, &n_tlhs, false);
 		fprintf(gfp, _("\n\nThe remainder is:\n"));
-		display_fractions_and_group(trhs, &n_trhs);
+		fractions_and_group(trhs, &n_trhs);
 		list_factor(trhs, &n_trhs, false);
 		fprintf(gfp, "\n");
 	} else {
@@ -1930,12 +1974,14 @@ char	*cp;
 	if (j) {
 		simp_divide(trhs, &n_trhs);
 		fprintf(gfp, _("Polynomial GCD (%d Euclidean algorithm iteration%s):\n"), j, (j == 1) ? "" : "s");
-		display_fractions_and_group(trhs, &n_trhs);
+		fractions_and_group(trhs, &n_trhs);
 		list_factor(trhs, &n_trhs, false);
 		fprintf(gfp, "\n");
 	} else {
 		fprintf(gfp, _("No univariate polynomial GCD found.\n"));
 	}
+	if (repeat_flag)
+		goto do_repeat;
 	return true;
 }
 
@@ -1949,7 +1995,7 @@ char	*cp;
 	long	v, last_v, v1, va[MAX_VARS];		/* Mathomatic variables */
 	int	vc = 0;					/* variable count */
 	int	i = 0, n;
-	int	success_flag = false, did_something = false, repeat_flag = false, using_flag;
+	int	success_flag = false, did_something = false, using_flag;
 	char	used[N_EQUATIONS];
 	char	*cp_start;
 	char	buf[MAX_CMD_LEN];
@@ -2154,10 +2200,13 @@ char	*cp;
 				}
 				blt(jmp_save, save_save, sizeof(jmp_save));
 #if     LIBRARY
-	                        if (gfp == stdout) {
-	                                free_result_str();
-	                                result_str = list_equation(i, false);
-	                                return(result_str != NULL);
+				free_result_str();
+				result_str = list_equation(i, false);
+				if (result_str == NULL)
+					return false;
+				if (gfp == stdout) {
+	                                displayed = true;
+					continue;
 	                        }
 #endif
 				if (flist_equation(i) > 0) {
@@ -2200,14 +2249,18 @@ char	*cp;
 			return false;
 		}
 		for (; i <= j; i++) {
+			if (n_lhs[i] > 0) {
 #if	LIBRARY
-			if (gfp == stdout) {
 				free_result_str();
 				result_str = list_equation(i, export_flag);
-				return(result_str != NULL);
-			}
+				if (result_str == NULL)
+					return false;
+				if (gfp == stdout) {
+					continue;
+				}
 #endif
-			list1_sub(i, export_flag);
+				list1_sub(i, export_flag);
+			}
 		}
 	} while (*cp);
 	return true;
@@ -2220,22 +2273,22 @@ int
 code_cmd(cp)
 char	*cp;
 {
-	int	i, j;
-	int	language = 0;
-	int	int_flag = false, displayed = false;
-	char	*cp1;
+	int			i, j;
+	enum language_list	language = C;
+	int			int_flag = false, displayed = false;
+	char			*cp1;
 
 	for (;; cp = skip_param(cp)) {
 		if (strcmp_tospace(cp, "c") == 0 || strcmp_tospace(cp, "c++") == 0) {
-			language = 0;
+			language = C;
 			continue;
 		}
 		if (strcmp_tospace(cp, "java") == 0) {
-			language = 1;
+			language = JAVA;
 			continue;
 		}
 		if (strcmp_tospace(cp, "python") == 0) {
-			language = 2;
+			language = PYTHON;
 			continue;
 		}
 		if (strcmp_tospace(cp, "int") == 0 || strcmp_tospace(cp, "integer") == 0) {
@@ -2300,25 +2353,25 @@ int
 variables_cmd(cp)
 char	*cp;
 {
-	int		i, j, k;
-	int		i1;
-	long		v1, last_v;		/* Mathomatic variables */
-	int		vc, cnt;		/* variable counts */
-	sort_type	va[MAX_VARS];
-	token_type	*p1;
-	int		n1;
-	int		lang_code = 0;
-	int		int_flag = false, imag_flag = false;
+	int			i, j, k;
+	int			i1;
+	long			v1, last_v;		/* Mathomatic variables */
+	int			vc, cnt;		/* variable counts */
+	sort_type		va[MAX_VARS];
+	token_type		*p1;
+	int			n1;
+	enum language_list	lang_code = 0;		/* default to no programming language */
+	int			int_flag = false, imag_flag = false;
 
 	if (strcmp_tospace(cp, "c") == 0 || strcmp_tospace(cp, "c++") == 0) {
 		cp = skip_param(cp);
-		lang_code = 1;
+		lang_code = C;
 	} else if (strcmp_tospace(cp, "java") == 0) {
 		cp = skip_param(cp);
-		lang_code = 2;
+		lang_code = JAVA;
 	} else if (strcmp_tospace(cp, "int") == 0 || strcmp_tospace(cp, "integer") == 0) {
 		cp = skip_param(cp);
-		lang_code = 1;
+		lang_code = C;
 		int_flag = true;
 	}
 	if (!get_range_eol(&cp, &i, &j)) {
@@ -2609,8 +2662,8 @@ char	*cp;
 			if (quickest_flag) {
 				simp_sub(i);
 			} else {
-				simpa_side(lhs[i], &n_lhs[i], quick_flag, frac_flag);
-				simpa_side(rhs[i], &n_rhs[i], quick_flag, frac_flag);
+				simpa_repeat_side(lhs[i], &n_lhs[i], quick_flag, frac_flag);
+				simpa_repeat_side(rhs[i], &n_rhs[i], quick_flag, frac_flag);
 			}
 			if (!return_result(i)) {
 				symb_flag = false;
@@ -2692,8 +2745,8 @@ char	*cp;
 				if (quickest_flag) {
 					simp_sub(i1);
 				} else {
-					simpa_side(lhs[i1], &n_lhs[i1], quick_flag, frac_flag);
-					simpa_side(rhs[i1], &n_rhs[i1], quick_flag, frac_flag);
+					simpa_repeat_side(lhs[i1], &n_lhs[i1], quick_flag, frac_flag);
+					simpa_repeat_side(rhs[i1], &n_rhs[i1], quick_flag, frac_flag);
 				}
 				for (k1 = 0; k1 < ARR_CNT(previous_solution_number); k1++) {
 					if (previous_solution_number[k1]) {
@@ -2729,7 +2782,7 @@ char	*cp;
 	long	v;				/* Mathomatic variable */
 	double	d;
 	char	buf[MAX_CMD_LEN];
-	int	valid_range = false, repeat_flag = false, power_flag = false;
+	int	valid_range = false, power_flag = false;
 	char	*cp1;
 
 	if (strcmp_tospace(cp, "number") == 0) {
@@ -3110,7 +3163,7 @@ char	*cp;
 		high_prec = true;
 		list_cmd("all");
 		high_prec = false;
-		gfp = stdout;
+		gfp = default_out;
 		fclose(fp);
 		rv = edit_sub(tmp_file);
 		unlink(tmp_file);
@@ -3167,7 +3220,7 @@ char	*cp;
 	high_prec = true;
 	rv = list_cmd("all");
 	high_prec = false;
-	gfp = stdout;
+	gfp = default_out;
 	if (fclose(fp))
 		rv = false;
 	if (rv) {
