@@ -1,7 +1,22 @@
 /*
  * Mathomatic symbolic differentiation routines and related commands.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -340,19 +355,21 @@ char	*cp;
 		}
 	}
 	if (no_vars(source, *nps, &v)) {
+#if	!SILENT
 		error(_("Current expression contains no variables; the derivative would be zero."));
 		return false;
+#endif
 	}
 	if (v == 0) {
 		if (!prompt_var(&v)) {
 			return false;
 		}
 	}
+#if	!SILENT
 	if (v != MATCH_ANY && !found_var(source, *nps, v)) {
 		error(_("Variable not found; the derivative would be zero."));
 		return false;
 	}
-#if	!SILENT
 	if (debug_level >= 0) {
 		list_var(v, 0);
 		if (n_rhs[cur_equation]) {
@@ -360,8 +377,11 @@ char	*cp;
 		} else {
 			printf(_("Differentiating with respect to (%s)"), var_str);
 		}
+		if (order != 1) {
+			printf(_(" %ld times"), order);
+		}
 		if (simplify_flag) {
-			printf(" and simplifying...\n");
+			printf(_(" and simplifying...\n"));
 		} else {
 			printf("...\n");
 		}
@@ -539,18 +559,14 @@ char	*cp;
 		}
 		cp = cp1;
 	}
-	if (no_vars(source, *nps, &v)) {
-		error(_("Current expression contains no variables."));
-		return false;
-	}
+	no_vars(source, *nps, &v);
 	if (v == 0) {
 		if (!prompt_var(&v)) {
 			return false;
 		}
 	}
 	if (!found_var(source, *nps, v)) {
-		error(_("Variable not found."));
-		return false;
+		warning(_("Variable not found."));
 	}
 	blt(rhs[our], source, *nps * sizeof(token_type));
 	our_nrhs = *nps;
@@ -593,11 +609,14 @@ char	*cp;
 		}
 	}
 #if	!SILENT
-	if (simplify_flag) {
-		printf(_("Computing and simplifying...\n"));
-	} else {
-		printf(_("Computing...\n"));
+	printf(_("Computing the Taylor series"));
+	if (n_rhs[cur_equation]) {
+		printf(_(" of the RHS"));
 	}
+	if (simplify_flag) {
+		printf(_(" and simplifying"));
+	}
+	printf("...\n");
 #endif
 	n = 0;
 	i1 = 0;
