@@ -1,11 +1,26 @@
 /*
  * Mathomatic global variables and arrays.
+ * Most global variables for Mathomatic are defined here and duplicated in "externs.h".
+ *
  * C initializes global variables and arrays to zero by default.
  * This is required for proper operation.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
- *
- * Most global variables for Mathomatic are defined here and duplicated in "externs.h".
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -96,6 +111,7 @@ int		uno;			/* number of unique factors stored in unique[] */
 
 /* misc. variables */
 sign_array_type	sign_array;		/* for keeping track of unique "sign" variables */
+FILE		*default_out;		/* file pointer where all gfp output goes by default */
 FILE		*gfp;			/* global output file pointer, for dynamically redirecting Mathomatic output */
 jmp_buf		jmp_save;		/* for setjmp(3) to longjmp(3) to when an error happens deep within this code */
 int		test_mode;		/* test mode flag (-t) */
@@ -115,6 +131,7 @@ int		pull_number;		/* equation space number to pull when using the library */
 #if	!SECURE
 int		security_level;		/* current enforced security level for session  */
 #endif
+int		repeat_flag;		/* true if the command is to repeat its function */
 
 /* library variables go here */
 char		*result_str;		/* returned result when using as library */
