@@ -3,7 +3,22 @@
  *
  * Everything that depends on the command table goes here.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -29,7 +44,7 @@ static com_type com_list[] = {
 /*	command name,	alternate name,		function,		usage,							information */
 {	"approximate",	NULL,			approximate_cmd,	"[equation-number-ranges]",				"Approximate all numerical values in equation spaces." },
 #if	!LIBRARY
-{	"calculate",	NULL,			calculate_cmd,		"[\"repeat\"] [\"factor\"] [variable number-of-iterations]",	"Temporarily plug in values for variables and approximate." },
+{	"calculate",	NULL,			calculate_cmd,		"[\"factor\"] [variable number-of-iterations]",		"Temporarily plug in values for variables and approximate.", "This command may be preceded with \"repeat\"." },
 #endif
 {	"clear",	NULL,			clear_cmd,		"[equation-number-ranges]",				"Delete expressions stored in memory so equation spaces can be reused.", "Tip: Use \"clear all\" to quickly restart Mathomatic." },
 {	"code",		NULL,			code_cmd,		"[\"c\" or \"java\" or \"python\" or \"integer\"] [equation-number-ranges]",	"Output C, Java, or Python code for the specified equations.", "Related commands: simplify, optimize, and variables" },
@@ -37,13 +52,13 @@ static com_type com_list[] = {
 {	"copy",		NULL,			copy_cmd,		"[equation-number-range]",				"Duplicate the contents of the specified equation spaces." },
 {	"derivative",	"differentiate",	derivative_cmd,		"[\"nosimplify\"] [variable or \"all\"] [order]",	"Symbolically differentiate and simplify, order times." },
 {	"display",	NULL,			display_cmd,		"[\"factor\"] [equation-number-ranges]",			"Display equation spaces in pretty multi-line (2D) fraction format." },
-{	"divide",	NULL,			divide_cmd,		"[variable]",						"Prompt for 2 numbers or polynomials and divide. Give result and GCD." },
+{	"divide",	NULL,			divide_cmd,		"[variable]",						"Prompt for 2 numbers or polynomials and divide. Give result and GCD.", "This command may be preceded with \"repeat\"." },
 {	"echo",		NULL,			echo_cmd,		"[text]",						"Output a line of text, followed by a newline." },
 #if	(UNIX || CYGWIN) && !SECURE && !LIBRARY
 {	"edit",		NULL,			edit_cmd,		"[file-name]",						"Edit all equation spaces or an input file, then read them in." },
 #endif
-{	"eliminate",	NULL,			eliminate_cmd,		"[\"repeat\"] variables or \"all\" [\"using\" equation-number]",	"Substitute the specified variables with solved equations." },
-{	"extrema",	NULL,			extrema_cmd,		"[variable] [order]",					"Show where the slope equals zero." },
+{	"eliminate",	NULL,			eliminate_cmd,		"variables or \"all\" [\"using\" equation-number]",	"Substitute the specified variables with solved equations.", "This command may be preceded with \"repeat\"." },
+{	"extrema",	NULL,			extrema_cmd,		"[variable] [order]",					"Show where the slope of the current equation equals zero." },
 {	"factor",	"collect",		factor_cmd,		"[\"number\" [integers]] or [\"power\"] [equation-number-range] [variables]",	"Factor variables in equation spaces or factor given integers." },
 {	"fraction",	"together",		fraction_cmd,		"[equation-number-range]",				"Convert expression to a single simple fraction, if any fractions are in it." },
 {	"help",		NULL,			help_cmd,		"[topic or command-names]",				"Short, built-in help and reference." },
@@ -54,9 +69,7 @@ static com_type com_list[] = {
 {	"list",		NULL,			list_cmd,		"[\"export\" or \"maxima\" or \"gnuplot\"] [equation-number-ranges]",	"Display equation spaces in single-line format." },
 {	"nintegrate",	NULL,			nintegrate_cmd,		"[\"trapezoid\"] variable [partitions]",		"Do numerical definite integration using Simpson's rule."},
 {	"optimize",	NULL,			optimize_cmd,		"[equation-number-range]",				"Split up equations into smaller, more efficient equations.", "Related command: code" },
-#if	!LIBRARY
 {	"pause",	NULL,			pause_cmd,		"[text]",						"Wait for user to press the Enter key. Optionally display a message." },
-#endif
 #if	(UNIX || CYGWIN) && !SECURE && !LIBRARY
 {	"plot",		NULL,			plot_cmd,		"[expression]",						"Automatically plot expression in 2D or 3D with Gnuplot." },
 #endif
@@ -72,12 +85,12 @@ static com_type com_list[] = {
 #endif
 {	"real",		NULL,			real_cmd,		"[variable]",						"Copy the real part of the current expression.", "Related command: imaginary" },
 {	"replace",	NULL,			replace_cmd,		"[variables [\"with\" expression]]",			"Substitute variables in the current equation with expressions." },
-{	"roots",	NULL,			roots_cmd,		"root real-part imaginary-part",			"Display all the roots of a complex number." },
+{	"roots",	NULL,			roots_cmd,		"root real-part imaginary-part",			"Display all the roots of a complex number.", "This command may be preceded with \"repeat\"." },
 #if	!SECURE
 {	"save",		NULL,			save_cmd,		"file-name",						"Save all equation spaces in a text file.", "Related command: read" },
 #endif
 {	"set",		NULL,			set_cmd,		"[[\"no\"] option] ...",				"Display, set, or save current session options.", "Tip: Type \"set\" by itself to show all current option settings." },
-{	"simplify",	NULL,			simplify_cmd,		"[\"sign\"] [\"symbolic\"] [\"quick\"] [\"quickest\"] [\"fraction\"] [equation-number-range]",	"Completely simplify expressions." },
+{	"simplify",	NULL,			simplify_cmd,		"[\"sign\"] [\"symbolic\"] [\"quick\"] [\"quickest\"] [\"fraction\"] [equation-number-range]",	"Completely simplify expressions.", "This command may be preceded with \"repeat\"." },
 {	"solve",	NULL,			solve_cmd,		"[\"verify\"] [\"for\"] variable or \"0\"",		"Solve the current equation for a variable or for zero." },
 {	"sum",		NULL,			sum_cmd,		"variable start end [step-size]",			"Compute the summation as variable goes from start to end.", "Related command: product" },
 #if	!LIBRARY
@@ -96,8 +109,10 @@ char	*example_strings[] = {
 	"derivative\n",
 	"pause\n",
 	"\n",
-	"; Solve and simplify an equation:\n",
+	"; Enter a common temperature conversion formula:\n",
 	"fahrenheit = (9*celsius/5) + 32\n",
+	"repeat calculate ; plug in values until an empty line is entered\n",
+	"; Solve for the other variable and simplify the result:\n",
 	"solve for celsius\n",
 	"simplify\n",
 	"variables ; show all variables that occur in an expression\n",
@@ -260,6 +275,7 @@ char	*cp;
 	int	len;
 	int	rv;
 	char	buf2[MAX_CMD_LEN];
+	int	our_repeat_flag = false;
 #if	!SECURE
 	FILE	*fp;
 	char	*filename;
@@ -330,10 +346,16 @@ char	*cp;
 	}
 /* See if the string pointed to by cp is a command. */
 /* If so, execute it. */
+do_repeat:
 	cp1 = cp;
 	while (*cp1 && !isspace(*cp1))
 		cp1++;
 	len = cp1 - cp;	/* length of possible command name in cp */
+	if (len == 6 && strncasecmp(cp, "repeat", 6) == 0) {
+		our_repeat_flag = true;
+		cp = skip_space(cp1);
+		goto do_repeat;
+	}
 	for (i = 0; i < ARR_CNT(com_list); i++) {
 		if ((len >= min(4, strlen(com_list[i].name)) && strncasecmp(cp, com_list[i].name, len) == 0)
 		    || (com_list[i].secondary_name && len >= min(4, strlen(com_list[i].secondary_name)) && strncasecmp(cp, com_list[i].secondary_name, len) == 0)) {
@@ -371,7 +393,7 @@ char	*cp;
 						error(_("Can't open redirected output file for writing."));
 						return false;
 					}
-					if (gfp != stdout) {
+					if (gfp != stdout && gfp != stderr && gfp != default_out) {
 						fclose(gfp);	/* make sure previous redirection file is closed */
 					}
 					gfp = fp;
@@ -381,11 +403,14 @@ char	*cp;
 			remove_trailing_spaces(buf2);
 			pull_number = 1;
 /* execute the command by calling the command function */
+			repeat_flag = our_repeat_flag;
 			rv = (*com_list[i].func)(buf2);
+			repeat_flag = false;
 #if	!SECURE
-			if (fp && gfp != stdout) {
-				fclose(gfp);
-				gfp = stdout;
+			if (fp && gfp != default_out) {
+				if (gfp != stdout && gfp != stderr)
+					fclose(gfp);
+				gfp = default_out;
 			}
 #endif
 #if	!SILENT
@@ -396,6 +421,10 @@ char	*cp;
 			return rv;
 		}
 	}
+	if (our_repeat_flag) {
+		error(_("Expecting command to repeat."));
+		return false;
+	}
 /* cp is not a command, so parse the expression */
 	i = next_espace();
 	input_column += (cp - cp_start);
@@ -404,6 +433,7 @@ char	*cp;
 
 /*
  * Display and process Mathomatic main prompt input that ends with a newline.
+ * Used by the read command.
  *
  * Return true if successful.
  */
@@ -422,7 +452,7 @@ char	*cp;	/* string to process, will be modified */
 		printf("<b>%s</b>", cp);	/* make input bold */
 	else
 		printf("%s", cp);
-	if (gfp != stdout) {
+	if (gfp != stdout && gfp != stderr) {
 		fprintf(gfp, "%d%s%s", cur_equation + 1, PROMPT_STR, cp);
 	}
 #endif
