@@ -1,9 +1,22 @@
 /*
  * Mathomatic integration routines and commands.
  *
- * These are very low level, so they don't do much.
- *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -296,6 +309,9 @@ char	*cp;
 		} else {
 			printf(_("Integrating with respect to (%s)"), var_str);
 		}
+		if (integrate_order != 1.0) {
+			printf(_(" %.0f times"), integrate_order);
+		}
 		printf(_(" and simplifying...\n"));
 	}
 #endif
@@ -590,7 +606,11 @@ char	*cp;
 			return false;
 		}
 	}
+#if	true
 	simp_loop(dest, &n1);
+#else
+	simpa_side(dest, &n1, false, false);
+#endif
 	if (n_rhs[cur_equation]) {
 		blt(lhs[i], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
 		n_lhs[i] = n_lhs[cur_equation];
