@@ -2,7 +2,22 @@
  * Mathomatic expression and equation display routines.
  * Color mode routines, too.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -76,7 +91,7 @@ reset_attr()
 
 /*
  * Set the current color on the display.
- * Subsequent output will have the color in carray[color].
+ * Subsequent output will have the color in carray[color % ARR_CNT(carray)].
  * Range is 0 to INT_MAX.
  */
 void
@@ -93,12 +108,12 @@ int	color;
 				printf("</font>");
 			}
 			if (bold_colors) {
-				printf("<font color=\"%s\">", bright_html_carray[color%ARR_CNT(bright_html_carray)]);
+				printf("<font color=\"%s\">", bright_html_carray[color % ARR_CNT(bright_html_carray)]);
 			} else {
-				printf("<font color=\"%s\">", html_carray[color%ARR_CNT(html_carray)]);
+				printf("<font color=\"%s\">", html_carray[color % ARR_CNT(html_carray)]);
 			}
 		} else {
-			printf("\033[%d;%dm", bold_colors, carray[color%ARR_CNT(carray)]);
+			printf("\033[%d;%dm", bold_colors, carray[color % ARR_CNT(carray)]);
 		}
 		cur_color = color;
 	}
@@ -220,13 +235,12 @@ int		n2;
  * Convert the passed Mathomatic variable to an ASCII variable name.
  * The ASCII variable name is stored in the global var_str[].
  *
- * Return length of variable name (number of ASCII characters).
+ * Return the length of the variable name string in var_str[].
+ * Nothing is displayed.
  *
  * If (lang_code == 0), use standard Mathomatic format.
- * If (lang_code == 1), make variable name C language compatible.
- * If (lang_code == 2), make variable name Java compatible.
- * If (lang_code == 3), make variable name Python compatible.
- * If lang_code is negative, create an exportable variable name: -1 for Maxima, -2 for other.
+ * If (lang_code > 0), make variable compatible with the language defined in the enumeration language_list defined in am.h
+ * If (lang_code < 0), create an exportable variable name: -1 for Maxima, -2 for other.
  */
 int
 list_var(v, lang_code)
@@ -257,7 +271,7 @@ int	lang_code;	/* language code */
 		case 0:
 			cp = "i#";
 			break;
-		case 3:
+		case PYTHON:
 			cp = "1j";
 			break;
 		default:
@@ -276,13 +290,13 @@ int	lang_code;	/* language code */
 		case 0:
 			cp = "e#";
 			break;
-		case 1:
+		case C:
 			cp ="M_E";
 			break;
-		case 2:
+		case JAVA:
 			cp = "Math.E";
 			break;
-		case 3:
+		case PYTHON:
 			cp = "math.e";
 			break;
 		default:
@@ -298,13 +312,13 @@ int	lang_code;	/* language code */
 		case 0:
 			cp = "pi#";
 			break;
-		case 1:
+		case C:
 			cp = "M_PI";
 			break;
-		case 2:
+		case JAVA:
 			cp = "Math.PI";
 			break;
-		case 3:
+		case PYTHON:
 			cp = "math.pi";
 			break;
 		default:
@@ -374,7 +388,7 @@ int	export_flag;	/* flag for exportable format (usually false) */
 		len += strlen(EQUATE_STRING);
 		len += list_string(rhs[n], n_rhs[n], NULL, export_flag);
 	}
-	len += 2;
+	len += 2;	/* for possible semicolon and terminating null character */
 	cp = (char *) malloc(len);
 	if (cp == NULL) {
 		error(_("Out of memory (can't malloc(3))."));
@@ -410,7 +424,7 @@ int		export_flag;
 		return NULL;
 	}
 	len = list_string(p1, n, NULL, export_flag);
-	len++;
+	len++;	/* for terminating null character */
 	cp = (char *) malloc(len);
 	if (cp == NULL) {
 		error(_("Out of memory (can't malloc(3))."));
@@ -455,7 +469,9 @@ int		export_flag;
 	int	len = 0;
 	char	buf[500], buf2[500];
 	int	export_precision;
+	int	cflag;		/* color flag */
 
+	cflag = (outflag && !export_flag);
 	if (string)
 		string[0] = '\0';
 	if (high_prec)
@@ -470,11 +486,11 @@ int		export_flag;
 			if (j > 0) {
 				cur_level--;
 				APPEND(")");
-				if (outflag && !export_flag)
+				if (cflag)
 					set_color(cur_level-min1);
 			} else {
 				cur_level++;
-				if (outflag && !export_flag)
+				if (cflag)
 					set_color(cur_level-min1);
 				APPEND("(");
 			}
@@ -551,7 +567,7 @@ int		export_flag;
 	for (j = cur_level - min1; j > 0;) {
 		APPEND(")");
 		j--;
-		if (outflag && !export_flag)
+		if (cflag)
 			set_color(j);
 	}
 	return len;
@@ -594,9 +610,9 @@ int		n;		/* length of expression */
  */
 int
 list_c_equation(en, language, int_flag)
-int	en;		/* equation space number */
-int	language;
-int	int_flag;	/* integer arithmetic flag */
+int			en;		/* equation space number */
+enum language_list	language;
+int			int_flag;	/* integer arithmetic flag */
 {
 	int	len = 0;
 
@@ -607,8 +623,13 @@ int	int_flag;	/* integer arithmetic flag */
 		len += fprintf(gfp, " = ");
 		len += list_code(rhs[en], &n_rhs[en], language, int_flag);
 	}
-	if (language != 2) {
+	switch (language) {
+	case C:
+	case JAVA:
 		len += fprintf(gfp, ";");
+		break;
+	default:
+		break;
 	}
 	fprintf(gfp, "\n");
 	return len;
@@ -622,10 +643,10 @@ int	int_flag;	/* integer arithmetic flag */
  */
 int
 list_code(equation, np, language, int_flag)
-token_type	*equation;	/* equation side pointer */
-int		*np;		/* pointer to length of equation side */
-int		language;	/* if 0, generate C code; if 1, generate Java code; if 2, generate Python code */
-int		int_flag;	/* integer arithmetic flag, should work with any language */
+token_type		*equation;	/* equation side pointer */
+int			*np;		/* pointer to length of equation side */
+enum language_list	language;	/* see enumeration language_list in am.h */
+int			int_flag;	/* integer arithmetic flag, should work with any language */
 {
 	int	i, j, k, i1, i2;
 	int	min1;
@@ -658,12 +679,17 @@ int		int_flag;	/* integer arithmetic flag, should work with any language */
 								equation[i2].token.operatr = TIMES;
 								equation[i2+1] = equation[i2-1];
 							} else {
-								if (int_flag || language > 1)
-									break;
-								if (language) {
-									len += fprintf(gfp, "Math.pow");
-								} else {
-									len += fprintf(gfp, "pow");
+								if (!int_flag) {
+									switch (language) {
+									case C:
+										len += fprintf(gfp, "pow");
+							 			break;
+									case JAVA:
+										len += fprintf(gfp, "Math.pow");
+										break;
+									default:
+										break;
+									}
 								}
 							}
 							break;
@@ -696,10 +722,10 @@ int		int_flag;	/* integer arithmetic flag, should work with any language */
 			}
 			break;
 		case VARIABLE:
-			if (int_flag && language <= 1 && equation[i].token.variable == IMAGINARY) {
+		  	if (int_flag && (language == C || language == JAVA) && equation[i].token.variable == IMAGINARY) {
 				len += fprintf(gfp, "1i");
 			} else {
-				list_var(equation[i].token.variable, language + 1);
+				list_var(equation[i].token.variable, language);
 				len += fprintf(gfp, "%s", var_str);
 			}
 			break;
@@ -723,7 +749,7 @@ int		int_flag;	/* integer arithmetic flag, should work with any language */
 				cp = MODULUS_STRING;
 				break;
 			case POWER:
-				if (int_flag || language > 1) {
+				if (int_flag || language == PYTHON) {
 					cp = "**";
 				} else {
 					cp = ", ";
