@@ -2,8 +2,25 @@
  * This file contains main() and the startup code for Mathomatic,
  * which is a small computer algebra system written entirely in C.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
- *
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
+ */
+
+/*
  * Output to stderr is only done in this file.  The rest of the Mathomatic code
  * should not output to stderr; error messages should use error() or go to stdout.
  *
@@ -42,10 +59,6 @@
 #if	!LIBRARY	/* This comments out this whole file if using as symbolic math library. */
 
 #include "includes.h"
-#if	UNIX || CYGWIN
-#include <sys/ioctl.h>
-#include <termios.h>
-#endif
 #if	TRAP_FPERRORS	/* Do not use this define!  Currently does not work. */
 #include <fenv.h>
 #endif
@@ -71,7 +84,8 @@ usage()
 	printf(_("  -v            Display version information, then exit.\n"));
 	printf(_("  -w            Wide output mode, sets unlimited width.\n"));
 	printf(_("  -x            Enable HTML/XHTML output mode.\n"));
-	printf(_("\nPlease refer to the %s man page for more information.\n"), prog_name);
+	printf(_("\nPlease refer to the Mathomatic man page for more information.\n"));
+	printf(_("The man page is viewed by typing \"man mathomatic\".\n"));
 }
 
 int
@@ -100,7 +114,8 @@ char	**argv;
 #endif
 	/* initialize the global variables */
 	init_gvars();
-	gfp = stdout;
+	default_out = stdout;	/* set default_out to any file you want to redirect output to */
+	gfp = default_out;
 
 	/* process command line options */
 	while ((i = getopt(argc, argv, "s:bqrtchuvwxm:")) >= 0) {
@@ -201,7 +216,7 @@ char	**argv;
 			printf(_("Secure "));
 #endif
 		printf("Mathomatic version %s (www.mathomatic.org)\n", VERSION);
-		printf("Copyright (C) 1987-2009 George Gesslein II.\n");
+		printf("Copyright (C) 1987-2010 George Gesslein II.\n");
 		printf(_("%d equation spaces available, %ld Kbytes per equation space.\n"),
 		    N_EQUATIONS, (long) n_tokens * sizeof(token_type) * 2L / 1000L);
 	}
@@ -258,7 +273,7 @@ char	**argv;
 		/* read in files specified on the command line, exit if error */
 		for (i = optind; i < argc && argv[i]; i++) {
 			if (strcmp(argv[i], "-") == 0) {
-				read_stdin();
+				main_io_loop();
 			} else if (!read_cmd(argv[i])) {
 				fprintf(stderr, _("Read of file \"%s\" failed.\n"), argv[i]);
 				exit_program(1);
@@ -266,7 +281,7 @@ char	**argv;
 		}
 #endif
 	}
-	read_stdin();		/* main input/output loop */
+	main_io_loop();		/* main input/output loop */
 	exit_program(0);	/* exit Mathomatic, doesn't return */
 	return(0);		/* so the compiler doesn't complain */
 }
@@ -275,7 +290,7 @@ char	**argv;
  * Repeatedly read a line of text from standard input and process the expression or command.
  */
 void
-read_stdin()
+main_io_loop()
 {
 	char	*cp = NULL;
 
@@ -308,6 +323,10 @@ set_signals()
 		rv = false;
 	if (signal(SIGQUIT, inthandler) == SIG_ERR)
 		rv = false;
+	if (signal(SIGTERM, exithandler) == SIG_ERR)
+		rv = false;
+	if (signal(SIGHUP, exithandler) == SIG_ERR)
+		rv = false;
 #if	UNIX || CYGWIN
 	if (signal(SIGWINCH, resizehandler) == SIG_ERR)
 		rv = false;
@@ -437,29 +456,17 @@ int	sig;
 	exit_program(1);
 }
 
-#if	UNIX || CYGWIN
 /*
- * Get the screen (window) width and height from the operating system.
- *
- * Sets the global integers screen_columns and screen_rows.
+ * Signal handler for proper exiting to the operating system.
  */
 void
-get_screen_size()
+exithandler(sig)
+int	sig;
 {
-	struct winsize	ws;
-
-	ws.ws_col = 0;
-	ws.ws_row = 0;
-	if (ioctl(1, TIOCGWINSZ, &ws) >= 0) {
-		if (ws.ws_col > 0) {
-			screen_columns = ws.ws_col;
-		}
-		if (ws.ws_row > 0) {
-			screen_rows = ws.ws_row;
-		}
-	}
+	exit_program(1);
 }
 
+#if	UNIX || CYGWIN
 /*
  * Window resize signal handler.
  */
