@@ -2,11 +2,25 @@
  * Calculate and display Pascal's triangle.
  *
  * Copyright (C) 2005 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <libgen.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <string.h>
@@ -41,8 +55,6 @@ main(int argc, char *argv[])
 {
 	struct winsize	ws;
 
-/*	prog_name = strdup(basename(argv[0])); */
-
 	ws.ws_col = 0;
 	ws.ws_row = 0;
 	ioctl(1, TIOCGWINSZ, &ws);
