@@ -8,6 +8,7 @@ void warning(const char *str);
 void error_huge(void);
 void error_bug(const char *str);
 void check_err(void);
+void get_screen_size(void);
 int init_mem(void);
 void init_gvars(void);
 void clean_up(void);
@@ -75,6 +76,7 @@ int calculate_cmd(char *cp);
 int clear_cmd(char *cp);
 int compare_es(int i, int j);
 int compare_cmd(char *cp);
+int display_fraction(double value);
 int divide_cmd(char *cp);
 int eliminate_cmd(char *cp);
 int display_cmd(char *cp);
@@ -134,7 +136,6 @@ double gcd(double d1, double d2);
 double gcd_verified(double d1, double d2);
 double my_round(double d1);
 int f_to_fraction(double d, double *numeratorp, double *denominatorp);
-int display_fraction(double value);
 int make_fractions(token_type *equation, int *np);
 /* globals.c */
 /* help.c */
@@ -167,19 +168,19 @@ char *list_expression(token_type *p1, int n, int export_flag);
 int list_string(token_type *p1, int n, char *string, int export_flag);
 int list_string_sub(token_type *p1, int n, int outflag, char *string, int export_flag);
 int int_expr(token_type *p1, int n);
-int list_c_equation(int en, int language, int int_flag);
-int list_code(token_type *equation, int *np, int language, int int_flag);
+int list_c_equation(int en, enum language_list language, int int_flag);
+int list_code(token_type *equation, int *np, enum language_list language, int int_flag);
 int flist_equation(int n);
 /* main.c */
 void usage(void);
 int main(int argc, char **argv);
-void read_stdin(void);
+void main_io_loop(void);
 int set_signals(void);
 int load_rc(void);
 void fphandler(int sig);
 void inthandler(int sig);
 void alarmhandler(int sig);
-void get_screen_size(void);
+void exithandler(int sig);
 void resizehandler(int sig);
 void exit_program(int exit_value);
 /* parse.c */
@@ -230,6 +231,7 @@ void simp2_divide(token_type *equation, int *np, long v, int fc_level);
 void simpb_side(token_type *equation, int *np, int uf_power_flag, int power_flag, int fc_level);
 void simple_frac_side(token_type *equation, int *np);
 void simpa_side(token_type *equation, int *np, int quick_flag, int frac_flag);
+void simpa_repeat_side(token_type *equation, int *np, int quick_flag, int frac_flag);
 int simp_loop(token_type *equation, int *np);
 int simp_pp(token_type *equation, int *np);
 int integer_root_simp(token_type *equation, int *np);
@@ -248,7 +250,7 @@ int solve_espace(int want, int have);
 int solve_sub(token_type *wantp, int wantn, token_type *leftp, int *leftnp, token_type *rightp, int *rightnp);
 /* super.c */
 void group_proc(token_type *equation, int *np);
-int display_fractions_and_group(token_type *equation, int *np);
+int fractions_and_group(token_type *equation, int *np);
 int make_fractions_and_group(int n);
 int super_factor(token_type *equation, int *np, int start_flag);
 /* unfactor.c */
