@@ -1,7 +1,22 @@
 /*
  * Mathomatic simplifying routines.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -224,14 +239,15 @@ int	n;	/* equation space number to simplify */
 }
 
 /*
- * For quick, mid-range simplification of an expression.
+ * For quick, mid-range simplification of an equation side.
+ * Trivial factoring is done.
  */
 void
 simp_side(equation, np)
 token_type	*equation;	/* pointer to the beginning of equation side to simplify */
 int		*np;		/* pointer to length of equation side */
 {
-	simp_ssub(equation, np, 0L, 1.0, true, true, 2 /* was 1 */);
+	simp_ssub(equation, np, 0L, 1.0, true, true, 6 /* was 2 */);
 }
 
 /*
@@ -261,7 +277,7 @@ long		v;		/* variable to factor, 0 for all variables */
 {
 	if (*np == 0)
 		return;
-	simp_ssub(equation, np, v, 0.0, v == 0, true, 2);
+	simp_ssub(equation, np, v, 0.0, v == 0, true, 6 /* was 2 */);
 }
 
 /*
@@ -499,7 +515,7 @@ simple_frac_side(equation, np)
 token_type	*equation;	/* pointer to the beginning of equation side */
 int		*np;		/* pointer to length of equation side */
 {
-	if (*np == 0)
+	if (*np <= 0)
 		return;
 
 	do {
@@ -509,16 +525,17 @@ int		*np;		/* pointer to length of equation side */
 			} while (poly_gcd_simp(equation, np));
 		} while (uf_power(equation, np));
 	} while (super_factor(equation, np, 2));
+	side_debug(2, equation, *np);
 
 	make_fractions(equation, np);
 	uf_tsimp(equation, np);
 	poly_factor(equation, np, true);
 	simpb_side(equation, np, true, false, 2);
+	fractions_and_group(equation, np);
 }
 
 /*
- * Main simplify code used by the simplify command.
- * This is the slowest and most thorough simplify of all.
+ * This is the slow and thorough simplify.
  * Applies many equivalent algebraic transformations and their inverses (like unfactor and factor),
  * then does generalized polynomial simplifications.
  *
@@ -580,7 +597,7 @@ int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two poly
 	do {
 		do {
 			do {
-				simp_ssub(equation, np, 0L, 1.0, false, true, 2);
+				simp_ssub(equation, np, 0L, 1.0, false, true, 6 /* was 2 */);
 			} while (poly_gcd_simp(equation, np));
 		} while (uf_power(equation, np));
 	} while (super_factor(equation, np, 2));
@@ -640,7 +657,7 @@ int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two poly
 	}
 /*	simpb_side(equation, np, true, true, 1); */
 	simp_constant_power(equation, np);
-	simp_ssub(equation, np, 0L, 1.0, true, true, 1);
+	simp_ssub(equation, np, 0L, 1.0, true, true, 5 /* was 1 */);
 	unsimp_power(equation, np);
 	make_fractions(equation, np);
 	factor_power(equation, np);
@@ -653,6 +670,35 @@ int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two poly
 	simpb_side(equation, np, true, !frac_flag, 2);
 }
 
+/*
+ * This routine is used by the simplify command,
+ * and is the slowest and most thorough simplify of all.
+ * It repeats the simplification until the smallest expression is achieved,
+ * if repeat_flag is true.
+ *
+ * Globals tes[], tlhs[], and trhs[] are wiped out.
+ */
+void
+simpa_repeat_side(equation, np, quick_flag, frac_flag)
+token_type	*equation;	/* pointer to the beginning of equation side to simplify */
+int		*np;		/* pointer to length of the equation side */
+int		quick_flag;	/* "simplify quick" option, simpler fractions with no (x+1)^2 expansion */
+int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two polynomials */
+{
+	simpa_side(equation, np, quick_flag, frac_flag);
+	if (repeat_flag) {
+		do {
+			n_tes = *np;
+			blt(tes, equation, n_tes * sizeof(token_type));
+			simpa_side(equation, np, quick_flag, frac_flag);
+		} while (*np < n_tes);
+		if (*np != n_tes) {
+			*np = n_tes;
+			blt(equation, tes, n_tes * sizeof(token_type));
+		}
+	}
+}
+
 /*
  * Commonly used quick simplify routine that doesn't factor.
  *
