@@ -1,7 +1,22 @@
 /*
- * Group and combine denominators symbolically for Mathomatic.
+ * Group and combine algebraic fractions for Mathomatic.
  *
- * Copyright (C) 1987-2009 George Gesslein II.
+ * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -94,11 +109,13 @@ int		*np;		/* pointer to length of equation side */
 
 /*
  * Make equation side ready for display.
+ * Converts non-integer constants in an equation side to fractions,
+ * when exactly equal to simple fractions.
  *
  * Return true if any fractions were created.
  */
 int
-display_fractions_and_group(equation, np)
+fractions_and_group(equation, np)
 token_type	*equation;
 int		*np;
 {
@@ -123,9 +140,9 @@ int	n;	/* equation space number */
 
 	if (n_lhs[n] <= 0)
 		return false;
-	rv = display_fractions_and_group(lhs[n], &n_lhs[n]);
+	rv = fractions_and_group(lhs[n], &n_lhs[n]);
 	if (n_rhs[n]) {
-		if (display_fractions_and_group(rhs[n], &n_rhs[n]))
+		if (fractions_and_group(rhs[n], &n_rhs[n]))
 			rv = true;
 	}
 	return rv;
